@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2003 CodeFactory AB
  * Copyright (C) 2003 Mikael Hallendal <micke@imendio.com>
@@ -24,15 +24,16 @@
 
 #include <glib.h>
 
-gboolean  dh_parse_file (const gchar  *path,
-			 GNode        *book_tree,
-			 GList       **keywords,
-			 GError      **error);
-#ifdef HAVE_LIBZ
-gboolean  dh_parse_gz_file (const gchar  *path,
-			 GNode        *book_tree,
-			 GList       **keywords,
-			 GError      **error);
-#endif
+G_BEGIN_DECLS
+
+gboolean dh_parser_read_file (const gchar  *path,
+                              gchar       **book_title,
+                              gchar       **book_name,
+                              gchar       **book_language,
+                              GNode       **book_tree,
+                              GList       **keywords,
+                              GError      **error);
+
+G_END_DECLS
 
 #endif /* __DH_PARSER_H__ */
